/* Exemplet visar hur man kan känna av vilken tangent som trycks ner
   och utifrån det göra olika uppdateringar av innehållet på sidan. */
// --------------------------------------------------
// Globala variabler
let startBtn;			// button-element för startknappen
let stopBtn;			// button-element för stoppknappen
let playGround;			// div-element för "spelplanen"

// ----- Bilen -----
let carElem;			// img-element för bilen
let carDir = 0;         // Bilens riktning (0, 1, 2, 3 = höger, nedåt, vänster, uppåt)
let carRot = 0;			// Rotation av bil(d)en
let carStep = 5;		// Antal pixlar som bilen ska förflytta sig i varje steg
let carTimerId = null;	// Timern för bilens förflyttning
const carTime = 25;     // Tid i ms mellan varje steg i förflyttningen
// --------------------------------------------------
// Initiering då webbsidan laddats in
function init() {
    // Referenser till element i gränssnittet
    startBtn = document.querySelector("#startBtn");
    stopBtn = document.querySelector("#stopBtn");
    playGround = document.querySelector("#playGround");
    carElem = document.querySelector("#car");
    // Händelsehanterare för meny och knappar
    startBtn.addEventListener("click", startGame);
    stopBtn.addEventListener("click", stopGame);
    // Händelsehanterare för tangenter för att styra bilen
    document.addEventListener("keydown", checkKey);
    // Aktivera/inaktivera meny och knappar
    startBtn.disabled = false;
    stopBtn.disabled = true;
} // Slut init
window.addEventListener("load", init);
// --------------------------------------------------
// Initiera spelet och starta bilens rörelse
function startGame() {
    startBtn.disabled = true;
    stopBtn.disabled = false;
    document.activeElement.blur(); // Knapparna sätts ur focus, så att webbsidan kommer i fokus igen
    // Detta behövs för att man ska kunna känna av händelsen keydown i Firefox efter att man klickat på en knapp.

    // Sätt bilen i startläge
    carElem.style.left = "10px";
    carElem.style.top = "40px";
    carDir = 0; // Riktning höger
    carRot = 0; // Ingen rotation
    carElem.style.transform = "rotate(0deg)";
    carTimerId = setInterval(moveCar, carTime); // Starta bilen
} // Slut startGame
// --------------------------------------------------
// Kontrollera tangenter och styr bilen. Anropas vid keydown.
function checkKey(e) {
    switch (e.code) {
        case "ArrowLeft":
        case "KeyZ":
            carDir--;  // Vrid åt vänster
            if (carDir < 0) carDir = 3;
            carRot -= 90;
            carElem.style.transform = "rotate(" + carRot + "deg)";
            break;
        case "ArrowRight":
        case "Slash":
            carDir++;  // Vrid åt höger
            if (carDir > 3) carDir = 0;
            carRot += 90;
            carElem.style.transform = "rotate(" + carRot + "deg)";
            break;
    }
} // Slut checkKey
// --------------------------------------------------
// Flytta bilen ett steg framåt i bilens riktning
function moveCar() {
    let p = playGround.getBoundingClientRect(); // Gränsvärden för spelplanen
    let c = carElem.getBoundingClientRect();    // Gränsvärden för bilen
    let x = parseInt(carElem.style.left);       // x-koordinat (left) för bilen
    let y = parseInt(carElem.style.top);        // y-koordinat (top) för bilen
    switch (carDir) {
        case 0: // Höger
            if (c.right + carStep <= p.right) x += carStep;
            break;
        case 1: // Nedåt
            if (c.bottom + carStep <= p.bottom) y += carStep;
            break;
        case 2: // Vänster
            if (c.left - carStep >= p.left) x -= carStep;
            break;
        case 3: // Uppåt
            if (c.top - carStep >= p.top) y -= carStep;
            break;
    }
    carElem.style.left = x + "px";
    carElem.style.top = y + "px";
} // Slut moveCar
// --------------------------------------------------
// Stoppa spelet
function stopGame() {
    if (carTimerId != null) clearInterval(carTimerId);
    carTimerId = null;
    startBtn.disabled = false;
    stopBtn.disabled = true;
} // Slut stopGame
// --------------------------------------------------
